# WOT: Waddington-OT #

Waddington-OT uses time-course data to infer how the probability distribution
of cells in gene-expression space evolves over time, by using the mathematical
approach of Optimal Transport (OT).


Read the [documentation](http://broadinstitute.github.io/wot).
